Original function for creating conda env from yaml before this was implemented in conda_create.
Usage
create_env_cli(
yaml_path = system.file(package = "echoconda", "conda/test.yml"),
conda = "auto",
force_new = FALSE,
verbose = TRUE
)Arguments
- yaml_path
Path to local or remote yaml file with conda build specifications.
- conda
The path to a
condaexecutable. Use"auto"to allowreticulateto automatically find an appropriatecondabinary. See Finding Conda andconda_binary()for more details.- force_new
If the conda env already exists, overwrite it with a new one (DEFAULT:
FALSE).- verbose
Print messages.