Find the path to one or more executable binary for each given software.
Usage
find_executables_remote(
path = NULL,
tool = c("bcftools", "gcta", "plink"),
verbose = TRUE
)Find the path to one or more executable binary for each given software.
find_executables_remote(
path = NULL,
tool = c("bcftools", "gcta", "plink"),
verbose = TRUE
)