Skip to contents

Install conda if it has not already been installed.

Usage

install_conda_reticulate(conda, verbose = TRUE, ...)

Arguments

conda

The path to a conda executable. Use "auto" to allow reticulate to automatically find an appropriate conda binary. See Finding Conda and conda_binary() for more details.

verbose

Print messages.

...

Additional arguments to be passed to install_miniconda.