Skip to contents

py_discover_config "This function enables callers to check which versions of Python will be discovered on a system as well as which one will be chosen for use with reticulate."

Usage

which_env(verbose = TRUE)

Arguments

verbose

Print messages.