Create a conda environment from a yaml file. By default, creates the "echoR" conda env to support echolocatoR.
Usage
yaml_to_env(
yaml_path = system.file(package = "echoconda", "conda", "echoR_mini.yml"),
method = c("basilisk", "reticulate"),
conda = "auto",
force_new = FALSE,
show_contents = FALSE,
verbose = TRUE,
...
)Arguments
- yaml_path
Path to local or remote yaml file with conda build specifications.
- method
Method to use to create the conda env:
- "basilisk" :
Uses the R package basilisk.
- "reticulate" :
Uses the R package reticulate.
- "cli" :
Uses a custom wrapper for conda's command line interface.
- conda
The path to a
condaexecutable. Use"auto"to allowreticulateto automatically find an appropriatecondabinary. See Finding Conda andconda_binary()for more details.- force_new
If the conda env already exists, overwrite it with a new one (DEFAULT:
FALSE).- show_contents
Show the contents of the yaml file (if used).
- verbose
Print messages.
- ...
Additional arguments passed to method-specific conda env build functions:
basilisk: create_env_basiliskreticulate: conda_createcli: create_env_cli
See also
Other conda:
activate_env(),
env_to_yaml(),
find_env_rlib()